﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'eo', {
	auto: 'Aŭtomata',
	bgColorTitle: 'Fona Koloro',
	colors: {
		'000': 'Nigra',
		'800000': 'Kaŝtankolora',
		'8B4513': 'Mezbruna',
		'2F4F4F': 'Ardezgriza',
		'008080': 'Marĉanaskolora',
		'000080': 'Maristblua',
		'4B0082': 'Indigokolora',
		'696969': 'Malhelgriza',
		B22222: 'Brikruĝa',
		A52A2A: 'Bruna',
		DAA520: 'Senbrilorkolora',
		'006400': 'Malhelverda',
		'40E0D0': 'Turkisblua',
		'0000CD': 'Reĝblua',
		'800080': 'Purpura',
		'808080': 'Griza',
		F00: 'Ruĝa',
		FF8C00: 'Malheloranĝkolora',
		FFD700: 'Orkolora',
		'008000': 'Verda',
		'0FF': 'Verdblua',
		'00F': 'Blua',
		EE82EE: 'Viola',
		A9A9A9: 'Mezgriza',
		FFA07A: 'Salmokolora',
		FFA500: 'Oranĝkolora',
		FFFF00: 'Flava',
		'00FF00': 'Limetkolora',
		AFEEEE: 'Helturkiskolora',
		ADD8E6: 'Helblua',
		DDA0DD: 'Prunkolora',
		D3D3D3: 'Helgriza',
		FFF0F5: 'Lavendkolora vangoŝminko',
		FAEBD7: 'Antikvablanka',
		FFFFE0: 'Helflava',
		F0FFF0: 'Vintromelonkolora',
		F0FFFF: 'Lazura',
		F0F8FF: 'Aliceblua',
		E6E6FA: 'Lavendkolora',
		FFF: 'Blanka',
		'1ABC9C': 'Fortverdblua',
		'2ECC71': 'Smeraldkolora',
		'3498DB': 'Brilblua',
		'9B59B6': 'Ametistkolora',
		'4E5F70': 'Grizblua',
		'F1C40F': 'Brilflava',
		'16A085': 'Malhelverdblua',
		'27AE60': 'Malhelsmeraldkolora',
		'2980B9': 'Fortblua',
		'8E44AD': 'Malhelviola',
		'2C3E50': 'Malsaturita Bluo',
		'F39C12': 'Oranĝkolora',
		'E67E22': 'Karotkolora',
		'E74C3C': 'Pale Ruĝa',
		'ECF0F1': 'Brile Arĝenta',
		'95A5A6': 'Helgrizverdblua',
		'DDD': 'Helgriza',
		'D35400': 'Kukurbokolora',
		'C0392B': 'Forte ruĝa',
		'BDC3C7': 'Arĝenta',
		'7F8C8D': 'Grizverdblua',
		'999': 'Malhelgriza'
	},
	more: 'Pli da Koloroj...',
	panelTitle: 'Koloroj',
	textColorTitle: 'Teksta Koloro'
} );
